@@ -418,7 +418,7 @@ setup_special_icon_list(GtkBuilder *gxml,
     } icons[] = {
         { N_("Home"), "user-home", "gnome-fs-desktop",
           DESKTOP_ICONS_SHOW_HOME, TRUE },
-        { N_("Filesystem"), "drive-harddisk", "gnome-dev-harddisk",
+        { N_("File System"), "drive-harddisk", "gnome-dev-harddisk",
           DESKTOP_ICONS_SHOW_FILESYSTEM, TRUE },
         { N_("Trash"), "user-trash", "gnome-fs-trash-empty",
           DESKTOP_ICONS_SHOW_TRASH, TRUE },
@@ -535,11 +535,7 @@ xfdesktop_settings_image_iconview_add(GtkTreeModel *model,
         name_utf8 = g_filename_to_utf8(name, name_length,
                                        NULL, NULL, NULL);
         if(name_utf8) {
-#if GLIB_CHECK_VERSION (2, 30, 0)
             size_string = g_format_size(file_size);
-#else
-            size_string = g_format_size_for_display(file_size);
-#endif
 
             /* Display the file name, file type, and file size in the tooltip. */
             name_markup = g_markup_printf_escaped(_("<b>%s</b>\nType: %s\nSize: %s"),
@@ -903,8 +899,7 @@ cb_image_selection_changed(GtkIconView *icon_view,
         xfconf_channel_set_string(panel->channel, buf, filename);
     }
 
-    g_list_foreach (selected_items, (GFunc)gtk_tree_path_free, NULL);
-    g_list_free(selected_items);
+    g_list_free_full(selected_items, xfdesktop_tree_path_free);
     g_free(current_filename);
     if(buf)
         g_free(buf);
@@ -1037,8 +1032,9 @@ cb_xfdesktop_chk_cycle_backdrop_toggled(GtkCheckButton *button,
 }
 
 static gboolean
-xfdesktop_spin_icon_size_timer(GtkSpinButton *button)
+xfdesktop_spin_icon_size_timer(gpointer user_data)
 {
+    GtkSpinButton *button = user_data;
     XfconfChannel *channel = g_object_get_data(G_OBJECT(button), "xfconf-chanel");
 
     TRACE("entering");
@@ -1065,14 +1061,10 @@ cb_xfdesktop_spin_icon_size_changed(GtkSpinButton *button,
     g_object_set_data(G_OBJECT(button), "xfconf-chanel", user_data);
 
     timer_id = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(button), "timer-id"));
-    if(timer_id != 0) {
+    if(timer_id != 0)
         g_source_remove(timer_id);
-        timer_id = 0;
-    }
 
-    timer_id = g_timeout_add(500,
-                             (GSourceFunc)xfdesktop_spin_icon_size_timer,
-                             button);
+    timer_id = g_timeout_add(500, xfdesktop_spin_icon_size_timer, button);
 
     g_object_set_data(G_OBJECT(button), "timer-id", GUINT_TO_POINTER(timer_id));
 }
@@ -1482,23 +1474,6 @@ suboptions_set_sensitive(GtkToggleButton *btn,
     gtk_widget_set_sensitive(box, gtk_toggle_button_get_active(btn));
 }
 
-static gint
-display_get_monitor_num(GdkDisplay *display, GdkMonitor *monitor)
-{
-    gint i;
-
-    g_return_val_if_fail(GDK_IS_DISPLAY(display), 0);
-    g_return_val_if_fail(GDK_IS_MONITOR(monitor), 0);
-
-    for(i=0; i<gdk_display_get_n_monitors(display); i++) {
-        if(monitor == gdk_display_get_monitor(display, i))
-            return i;
-    }
-
-    g_warning("unable to get the monitor number");
-    return 0;
-}
-
 static void
 cb_update_background_tab(WnckWindow *wnck_window,
                          gpointer user_data)
@@ -1525,7 +1500,7 @@ cb_update_background_tab(WnckWindow *wnck_window,
     window = gtk_widget_get_window(panel->image_iconview);
     display = gdk_window_get_display(window);
     monitor = gdk_display_get_monitor_at_window(display, window);
-    monitor_num = display_get_monitor_num(display, monitor);
+    monitor_num = xfdesktop_get_monitor_num(display, monitor);
     monitor_name = xfdesktop_get_monitor_name_from_gtk_widget(panel->image_iconview, monitor_num);
 
     /* Most of the time we won't change monitor, screen, or workspace so try
@@ -1824,7 +1799,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     /* tooltip options */
     chk_show_tooltips = GTK_WIDGET(gtk_builder_get_object(main_gxml, "chk_show_tooltips"));
     spin_tooltip_size = GTK_WIDGET(gtk_builder_get_object(main_gxml, "spin_tooltip_size"));
-    gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_tooltip_size), 128);
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_tooltip_size), 64);
 
     /* connect up the signals */
     g_signal_connect(G_OBJECT(chk_custom_font_size), "toggled",
@@ -1997,6 +1972,10 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
 
 
     /* Menus Tab */
+    w = GTK_WIDGET(gtk_builder_get_object(main_gxml, "chk_show_delete_option"));
+    xfconf_g_property_bind(channel, DESKTOP_MENU_DELETE, G_TYPE_BOOLEAN,
+                           G_OBJECT(w), "active");
+
     w = GTK_WIDGET(gtk_builder_get_object(main_gxml, "chk_show_desktop_menu"));
     xfconf_g_property_bind(channel, SHOW_DESKTOP_MENU_PROP, G_TYPE_BOOLEAN,
                            G_OBJECT(w), "active");
@@ -2138,7 +2117,7 @@ main(int argc, char **argv)
     GtkBuilder *gxml;
     gint screen;
     GError *error = NULL;
-    AppearancePanel *panel = g_new0(AppearancePanel, 1);
+    AppearancePanel *panel;
 
 #ifdef G_ENABLE_DEBUG
     /* do NOT remove this line. If something doesn't work,
@@ -2148,10 +2127,6 @@ main(int argc, char **argv)
 
     xfce_textdomain(GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
-#if !GLIB_CHECK_VERSION(2, 32, 0)
-    g_thread_init(NULL);
-#endif
-
     if(!gtk_init_with_args(&argc, &argv, "", option_entries, PACKAGE, &error)) {
         if(G_LIKELY(error)) {
             g_printerr("%s: %s.\n", G_LOG_DOMAIN, error->message);
@@ -2166,7 +2141,7 @@ main(int argc, char **argv)
 
     if(G_UNLIKELY(opt_version)) {
         g_print("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, VERSION, xfce_version_string());
-        g_print("%s\n", "Copyright (c) 2004-2019");
+        g_print("%s\n", "Copyright (c) 2004-2020");
         g_print("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print("\n");
@@ -2197,6 +2172,7 @@ main(int argc, char **argv)
     }
 
     channel = xfconf_channel_new(XFDESKTOP_CHANNEL);
+    panel = g_new0(AppearancePanel, 1);
 
     if(opt_enable_debug)
         xfdesktop_debug_set(TRUE);
