@@ -65,6 +65,8 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 
+#include <cairo-xlib.h>
+
 #ifdef ENABLE_DESKTOP_ICONS
 #include "xfdesktop-icon-view.h"
 #include "xfdesktop-window-icon-manager.h"
@@ -316,13 +318,13 @@ set_real_root_window_surface(GdkScreen *gscreen,
                              cairo_surface_t *surface)
 {
 #ifndef DISABLE_FOR_BUG7442
-    Window xid;
+    Pixmap pixmap_id;
     GdkDisplay *display;
     GdkWindow *groot;
     cairo_pattern_t *pattern;
 
     groot = gdk_screen_get_root_window(gscreen);
-    xid = GDK_WINDOW_XID(groot);
+    pixmap_id = cairo_xlib_surface_get_drawable (surface);
 
     display = gdk_screen_get_display(gscreen);
     gdk_x11_display_error_trap_push(display);
@@ -331,7 +333,7 @@ set_real_root_window_surface(GdkScreen *gscreen,
     gdk_property_change(groot,
             gdk_atom_intern("_XROOTPMAP_ID", FALSE),
             gdk_atom_intern("PIXMAP", FALSE), 32,
-            GDK_PROP_MODE_REPLACE, (guchar *)&xid, 1);
+            GDK_PROP_MODE_REPLACE, (guchar *)&pixmap_id, 1);
     /* and set the root window's BG surface, because aterm is somewhat lame. */
     pattern = cairo_pattern_create_for_surface(surface);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
@@ -438,7 +440,7 @@ set_accountsservice_user_bg(const gchar *background)
     if (variant != NULL) {
         g_variant_unref (variant);
     } else {
-        g_warning ("Failed to set the background '%s': %s", background, error->message);
+        g_warning ("Failed to register the newly set background with AccountsService '%s': %s", background, error->message);
         g_clear_error (&error);
     }
 
@@ -456,9 +458,6 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
     GdkRectangle rect;
     cairo_region_t *clip_region = NULL;
     gint i, monitor = -1, current_workspace;
-#ifdef G_ENABLE_DEBUG
-    gchar *monitor_name = NULL;
-#endif
 
     TRACE("entering");
 
@@ -500,11 +499,8 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
     }
 
 #ifdef G_ENABLE_DEBUG
-    monitor_name = gdk_screen_get_monitor_plug_name(gscreen, monitor);
-
-    XF_DEBUG("backdrop changed for workspace %d, monitor %d (%s)", current_workspace, monitor, monitor_name);
-
-    g_free(monitor_name);
+    XF_DEBUG("backdrop changed for workspace %d, monitor %d (%s)", current_workspace, monitor,
+             gdk_monitor_get_model(gdk_display_get_monitor(display, monitor)));
 #endif
 
     if(xfce_desktop_get_n_monitors(desktop) > 1
@@ -1254,7 +1250,7 @@ xfce_desktop_unrealize(GtkWidget *widget)
     gtk_widget_set_mapped(widget, FALSE);
 
     gtk_container_forall(GTK_CONTAINER(widget),
-                         (GtkCallback)gtk_widget_unrealize,
+                         xfdesktop_widget_unrealize,
                          NULL);
 
     g_signal_handlers_disconnect_by_func(G_OBJECT(desktop->priv->gscreen),
@@ -1271,7 +1267,6 @@ xfce_desktop_unrealize(GtkWidget *widget)
 
 #ifndef DISABLE_FOR_BUG7442
     gdk_property_delete(groot, gdk_atom_intern("_XROOTPMAP_ID", FALSE));
-    gdk_property_delete(groot, gdk_atom_intern("ESETROOT_PMAP_ID", FALSE));
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gdk_window_set_background_pattern(groot, NULL);
 G_GNUC_END_IGNORE_DEPRECATIONS
@@ -1906,9 +1901,11 @@ xfce_desktop_popup_secondary_root_menu(XfceDesktop *desktop,
 }
 
 void
-xfce_desktop_refresh(XfceDesktop *desktop, gboolean advance_wallpaper)
+xfce_desktop_refresh(XfceDesktop *desktop,
+                     gboolean advance_wallpaper,
+                     gboolean all_monitors)
 {
-    gint i, current_workspace;
+    gint i, current_workspace, current_monitor_num = -1;
 
     TRACE("entering");
 
@@ -1923,10 +1920,19 @@ xfce_desktop_refresh(XfceDesktop *desktop, gboolean advance_wallpaper)
 
     current_workspace = xfce_desktop_get_current_workspace(desktop);
 
+    if(!all_monitors) {
+        GdkDisplay *display = gdk_screen_get_display(desktop->priv->gscreen);
+        current_monitor_num = xfdesktop_get_current_monitor_num(display);
+    }
+
     /* reload backgrounds */
     for(i = 0; i < xfce_desktop_get_n_monitors(desktop); i++) {
         XfceBackdrop *backdrop;
 
+        if(!all_monitors && current_monitor_num != i) {
+            continue;
+        }
+
         backdrop = xfce_workspace_get_backdrop(desktop->priv->workspaces[current_workspace], i);
 
         if(advance_wallpaper) {
@@ -1956,18 +1962,18 @@ xfce_desktop_arrange_icons(XfceDesktop *desktop)
 gboolean
 xfce_desktop_get_cycle_backdrop(XfceDesktop *desktop)
 {
-    gint monitor;
+    gint           monitor_num;
+    GdkDisplay    *display;
     XfceWorkspace *workspace;
     XfceBackdrop  *backdrop;
 
     g_return_val_if_fail(XFCE_IS_DESKTOP(desktop), FALSE);
 
-    xfce_gdk_screen_get_active(&monitor);
-    if(&monitor == NULL)
-        return FALSE;
+    display = gdk_screen_get_display(desktop->priv->gscreen);
+    monitor_num = xfdesktop_get_current_monitor_num(display);
 
     workspace = desktop->priv->workspaces[desktop->priv->current_workspace];
-    backdrop = xfce_workspace_get_backdrop(workspace, monitor);
+    backdrop = xfce_workspace_get_backdrop(workspace, monitor_num);
 
     return xfce_backdrop_get_cycle_backdrop(backdrop);
 }
