@@ -256,6 +256,62 @@ xfdesktop_file_utils_get_display_name(GFile *file,
     return display_name;
 }
 
+/**
+ * xfdesktop_file_utils_next_new_file_name
+ * @filename : the filename which will be used as the basis/default
+ * @folder : the directory to search for a free filename
+ *
+ * Returns a filename that is like @filename with the possible addition of
+ * a number to differentiate it from other similarly named files. In other words
+ * it searches @folder for incrementally named files starting from @file_name
+ * and returns the first available increment.
+ *
+ * e.g. in a folder with the following files:
+ * - file
+ * - empty
+ * - file_copy
+ *
+ * Calling this functions with the above folder and @filename equal to 'file' the returned
+ * filename will be 'file (copy 1)'.
+ *
+ * The caller is responsible to free the returned string using g_free() when no longer needed.
+ *
+ * Code extracted and adapted from on thunar_util_next_new_file_name.
+ *
+ * Return value: pointer to the new filename.
+ **/
+gchar*
+xfdesktop_file_utils_next_new_file_name(const gchar *filename,
+                                        const gchar *folder)
+{
+  unsigned long   file_name_size  = strlen(filename);
+  unsigned        count           = 0;
+  gboolean        found_duplicate = FALSE;
+  gchar          *extension       = NULL;
+  gchar          *new_name        = g_strdup(filename);
+
+  extension = strrchr(filename, '.');
+  if (!extension || extension == filename)
+    extension = "";
+  else
+    file_name_size -= strlen(extension);
+
+  /* loop until new_name is unique */
+  while(TRUE)
+    {
+      GFile *file = g_file_new_build_filename(folder, new_name, NULL);
+      found_duplicate = g_file_query_exists(file, NULL);
+      g_object_unref(file);
+
+      if (!found_duplicate)
+        break;
+      g_free(new_name);
+      new_name = g_strdup_printf(_("%.*s (copy %u)%s"), (int) file_name_size, filename, ++count, extension ? extension : "");
+    }
+
+  return new_name;
+}
+
 GList *
 xfdesktop_file_utils_file_icon_list_to_file_list(GList *icon_list)
 {
@@ -331,8 +387,7 @@ xfdesktop_file_utils_file_list_to_uri_array(GList *file_list)
 void
 xfdesktop_file_utils_file_list_free(GList *file_list)
 {
-  g_list_foreach(file_list, (GFunc) g_object_unref, NULL);
-  g_list_free(file_list);
+    g_list_free_full(file_list, g_object_unref);
 }
 
 static GdkPixbuf *xfdesktop_fallback_icon = NULL;
@@ -1245,6 +1300,7 @@ xfdesktop_file_utils_execute(GFile *working_directory,
     if(fileman_proxy) {
         GError *error = NULL;
         gchar *working_dir = working_directory != NULL ? g_file_get_uri(working_directory) : NULL;
+        const gchar *path_prop;
         gchar *uri = g_file_get_uri(file);
         gchar *display_name = g_strdup(gdk_display_get_name(gdk_screen_get_display(screen)));
         gchar *startup_id = g_strdup_printf("_TIME%d", gtk_get_current_event_time());
@@ -1270,7 +1326,11 @@ xfdesktop_file_utils_execute(GFile *working_directory,
                 if(path != NULL) {
                     rc = xfce_rc_simple_open(path, TRUE);
                     if(rc != NULL) {
-                        working_dir = g_strdup(xfce_rc_read_entry(rc, "Path", NULL));
+                        path_prop = xfce_rc_read_entry(rc, "Path", NULL);
+                        if(xfce_str_is_empty(path_prop))
+                            working_dir = g_strdup(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP));
+                        else
+                            working_dir = g_strdup(path_prop);
                         xfce_rc_close(rc);
                     }
                     g_free(path);
