@@ -101,10 +101,11 @@ G_DEFINE_TYPE_EXTENDED(XfdesktopSpecialFileIcon, xfdesktop_special_file_icon,
                        XFDESKTOP_TYPE_FILE_ICON, 0,
                        G_IMPLEMENT_INTERFACE(THUNARX_TYPE_FILE_INFO,
                                              xfdesktop_special_file_icon_tfi_init)
+                       G_ADD_PRIVATE(XfdesktopSpecialFileIcon)
                        )
 #else
-G_DEFINE_TYPE(XfdesktopSpecialFileIcon, xfdesktop_special_file_icon,
-              XFDESKTOP_TYPE_FILE_ICON)
+G_DEFINE_TYPE_WITH_PRIVATE(XfdesktopSpecialFileIcon, xfdesktop_special_file_icon,
+                           XFDESKTOP_TYPE_FILE_ICON)
 #endif
 
 
@@ -116,8 +117,6 @@ xfdesktop_special_file_icon_class_init(XfdesktopSpecialFileIconClass *klass)
     XfdesktopIconClass *icon_class = (XfdesktopIconClass *)klass;
     XfdesktopFileIconClass *file_icon_class = (XfdesktopFileIconClass *)klass;
 
-    g_type_class_add_private(klass, sizeof(XfdesktopSpecialFileIconPrivate));
-
     gobject_class->finalize = xfdesktop_special_file_icon_finalize;
 
     icon_class->peek_pixbuf = xfdesktop_special_file_icon_peek_pixbuf;
@@ -133,16 +132,12 @@ xfdesktop_special_file_icon_class_init(XfdesktopSpecialFileIconClass *klass)
     file_icon_class->peek_file_info = xfdesktop_special_file_icon_peek_file_info;
     file_icon_class->peek_filesystem_info = xfdesktop_special_file_icon_peek_filesystem_info;
     file_icon_class->peek_file = xfdesktop_special_file_icon_peek_file;
-    file_icon_class->can_rename_file = (gboolean (*)(XfdesktopFileIcon *))gtk_false;
-    file_icon_class->can_delete_file = (gboolean (*)(XfdesktopFileIcon *))gtk_false;
 }
 
 static void
 xfdesktop_special_file_icon_init(XfdesktopSpecialFileIcon *icon)
 {
-    icon->priv = G_TYPE_INSTANCE_GET_PRIVATE(icon,
-                                             XFDESKTOP_TYPE_SPECIAL_FILE_ICON,
-                                             XfdesktopSpecialFileIconPrivate);
+    icon->priv = xfdesktop_special_file_icon_get_instance_private(icon);
 }
 
 static void
